# AnalysisS.tcl - takes output from static analyses
# Units: kip, in
# Kevin Mackie, 2001/07/16
# mackie@ce.berkeley.edu
#
# Takes output from G3 static analyses (called from bridge
# input file) and outputs data to files for computation of UCSD
# output quantities

proc AnalysisS {skew L LoH fy fc rho_s DcDs ksoil wt rhos_trans param_num} {

# constants from GenerateBridge.tcl (should be checked for updates)
set deck_depth 7.0
set gamma [expr 150.0/1000/1728]
set A 8960.0
set g 386.4

# generate appropriate vaiables from input parameters
set pi [expr acos(-1.0)]
set Ds [expr $deck_depth*12.0]
set Dcol [expr $Ds*$DcDs]
set Ht [expr $L/$LoH]

# possible weight variations from GenerateBridge
# note the complete span is used here for the complete mass
set trib [expr $gamma*$A*$L*2.0]
set cur_load_ratio [expr $trib/($pi/4.0*pow($Dcol,2)*$fc)]
set wt_add [expr $cur_load_ratio*$wt]
set axial_load_ratio [expr $cur_load_ratio+$wt_add]
set smass [expr  $axial_load_ratio*($pi/4.0*pow($Dcol,2)*$fc)/$g]

# ---------------------------------------------------------------
# filenames of pushover data for yield information (longitudinal)
set fstubl [format "sl%04i" $param_num]
set fstubt [format "st%04i" $param_num]

set kyf [format "%ssf015.out" $fstubl]
set kyd [format "%ssd015.out" $fstubl]
set fyd [format "%snd081.out" $fstubl]

# load yield force/displacement data and parse
# strip off gap related jumps later in pushover
source FyUy.tcl
set fylong [FyUy $fyd]
scan $fylong "%f %f %f %f" uy ucap int_load ey
set Cyl [expr $int_load/$smass]

# -------------------------------------------------------------
# repeat parsing for curvature yield data (longitudinal)
source MyKy.tcl
set fylong [MyKy $kyf $kyd 1]
scan $fylong "%f %f" ky kcap

# -------------------------------------------------------------
# filenames of pushover data for yield information (transverse)
set kyft [format "%ssf015.out" $fstubt]
set kydt [format "%ssd015.out" $fstubt]
set fydt [format "%snd082.out" $fstubt]

# load yield force/displacement data and parse
# strip off gap related jumps later in pushover
source FyUy.tcl
set fylong [FyUy $fydt]
scan $fylong "%f %f %f %f" uyt ucapt int_load eyt
set Cyt [expr $int_load/$smass]

# -------------------------------------------------------------
# repeat parsing for curvature yield data (transverse)
source MyKy.tcl
set fylong [MyKy $kyft $kydt 2]
scan $fylong "%f %f" kyt kcapt

# ------------------------------------------------
# write table of summary information to file
set fstub [format "fs%04i" $param_num]
set file [open [format "%s.out" $fstub] "w"]

puts $file "Axial load ratio       $axial_load_ratio"
puts $file "Yield disp. long.      $uy"
puts $file "Yield curv. long.      $ky"
puts $file "Yield disp. trans.     $uyt"
puts $file "Yield curv. trans.     $kyt"
puts $file "Capacity Cy long.      $Cyl"
puts $file "Capacity Cy trans.     $Cyt"
puts $file "Yield Energy long.     $ey"
puts $file "Yield Energy trans.    $eyt"

close $file

}
